## Code
* [base.py](/experimental-design/models/base.py) - Contains the code for the base classes used in all model definitions in this work.
* [bilayers.py](/experimental-design/models/bilayers.py) - Defines the DMPC and DPPC/RaLPS bilayer models.
* [magnetic.py](/experimental-design/models/magnetic.py) - Defines the magnetic YIG sample.
* [monolayers.py](/experimental-design/models/monolayers.py) - Defines the DPPG monolayer model.
* [samples.py](/experimental-design/models/samples.py) - Defines a selection of "standard" layer models of varying complexity.
* [parsing.py](/experimental-design/models/parsing.py) - Contains code for translating chemical formulae into a dictionary of elements contained within the formula.
